==> jc-1.4.0.tar.gz: java/net/URLClassLoader__24RemoteResource.h <==
// final class java.net.URLClassLoader$RemoteResource

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 7e226663297a0266 java_net_URLClassLoader__24RemoteResource
// @dep_class 9d385c5a860bc53d java_net_URLClassLoader__24Resource

// header file dependencies
// @dep_header java_net_URLClassLoader__24Resource

#include "java/net/URLClassLoader__24Resource.h"

#ifndef _JC_java_net_URLClassLoader__24RemoteResource_H_
#define _JC_java_net_URLClassLoader__24RemoteResource_H_

// Forward structure declarations
struct _jc_java_io_InputStream$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_net_URL$object;
struct _jc_java_net_URLClassLoader__24RemoteURLLoader$object;

// Typedefs
typedef struct _jc_java_net_URLClassLoader__24RemoteResource$sub_refs	_jc_java_net_URLClassLoader__24RemoteResource$sub_refs;
typedef struct _jc_java_net_URLClassLoader__24RemoteResource$sub_nonrefs	_jc_java_net_URLClassLoader__24RemoteResource$sub_nonrefs;
typedef struct _jc_java_net_URLClassLoader__24RemoteResource$refs	_jc_java_net_URLClassLoader__24RemoteResource$refs;
typedef struct _jc_java_net_URLClassLoader__24RemoteResource$nonrefs	_jc_java_net_URLClassLoader__24RemoteResource$nonrefs;
typedef struct _jc_java_net_URLClassLoader__24RemoteResource$object	_jc_java_net_URLClassLoader__24RemoteResource$object;

typedef const struct _jc_java_net_URLClassLoader__24RemoteResource$vmethods	_jc_java_net_URLClassLoader__24RemoteResource$vmethods;
typedef const struct _jc_java_net_URLClassLoader__24RemoteResource$vtable	_jc_java_net_URLClassLoader__24RemoteResource$vtable;
typedef const struct _jc_java_net_URLClassLoader__24RemoteResource$vtype	_jc_java_net_URLClassLoader__24RemoteResource$vtype;

// Constructors
extern void _jc_java_net_URLClassLoader__24RemoteResource$method$_init$2c447d2563fff7fe(_jc_env *, struct _jc_java_net_URLClassLoader__24RemoteResource$object *, struct _jc_java_net_URLClassLoader__24RemoteURLLoader$object *, struct _jc_java_lang_String$object *, struct _jc_java_net_URL$object *, struct _jc_java_io_InputStream$object *, jint);

// Virtual methods
extern struct _jc_java_io_InputStream$object *_jc_java_net_URLClassLoader__24RemoteResource$method$getInputStream$13cf75a12cabb343(_jc_env *, struct _jc_java_net_URLClassLoader__24RemoteResource$object *);
extern jint _jc_java_net_URLClassLoader__24RemoteResource$method$getLength$b9eaa8ec0a00f23d(_jc_env *, struct _jc_java_net_URLClassLoader__24RemoteResource$object *);
extern struct _jc_java_net_URL$object *_jc_java_net_URLClassLoader__24RemoteResource$method$getURL$f8efe3e882b98c02(_jc_env *, struct _jc_java_net_URLClassLoader__24RemoteResource$object *);

// Virtual method descriptors
extern _jc_method _jc_java_net_URLClassLoader__24RemoteResource$method_info$getInputStream$13cf75a12cabb343;
extern _jc_method _jc_java_net_URLClassLoader__24RemoteResource$method_info$getLength$b9eaa8ec0a00f23d;
extern _jc_method _jc_java_net_URLClassLoader__24RemoteResource$method_info$getURL$f8efe3e882b98c02;

// Virtual methods structure
struct _jc_java_net_URLClassLoader__24RemoteResource$vmethods {
	struct _jc_java_io_InputStream$object	*(*getInputStream$13cf75a12cabb343)(_jc_env *, struct _jc_java_net_URLClassLoader__24RemoteResource$object *);
	jint	(*getLength$b9eaa8ec0a00f23d)(_jc_env *, struct _jc_java_net_URLClassLoader__24RemoteResource$object *);
	struct _jc_java_net_URL$object	*(*getURL$f8efe3e882b98c02)(_jc_env *, struct _jc_java_net_URLClassLoader__24RemoteResource$object *);
};

// Vtable
struct _jc_java_net_URLClassLoader__24RemoteResource$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_net_URLClassLoader__24Resource$vmethods	java_net_URLClassLoader__24Resource;
	_jc_java_net_URLClassLoader__24RemoteResource$vmethods	java_net_URLClassLoader__24RemoteResource;
};

// Vtype
struct _jc_java_net_URLClassLoader__24RemoteResource$vtype {
	_jc_type			type;
	_jc_java_net_URLClassLoader__24RemoteResource$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_net_URLClassLoader__24RemoteResource$sub_refs {
	struct _jc_java_net_URL$object	*url;
	struct _jc_java_io_InputStream$object	*stream;
};

// Reference instance fields (object)
struct _jc_java_net_URLClassLoader__24RemoteResource$refs {
    _jc_java_net_URLClassLoader__24RemoteResource$sub_refs	java_net_URLClassLoader__24RemoteResource;
    _jc_java_net_URLClassLoader__24Resource$sub_refs	java_net_URLClassLoader__24Resource;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_net_URLClassLoader__24RemoteResource$sub_nonrefs {
	jint	length;
};

// Non-reference instance fields (object)
struct _jc_java_net_URLClassLoader__24RemoteResource$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_net_URLClassLoader__24Resource$sub_nonrefs	java_net_URLClassLoader__24Resource;
    _jc_java_net_URLClassLoader__24RemoteResource$sub_nonrefs	java_net_URLClassLoader__24RemoteResource;
};

// Object instance structure
struct _jc_java_net_URLClassLoader__24RemoteResource$object {
	_jc_java_net_URLClassLoader__24RemoteResource$refs	refs[0];
	_jc_word		lockword;
	_jc_java_net_URLClassLoader__24RemoteResource$vtype	*vtype;
	_jc_java_net_URLClassLoader__24RemoteResource$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_net_URLClassLoader__24RemoteResource$vtype _jc_java_net_URLClassLoader__24RemoteResource$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_net_URLClassLoader__24RemoteResource, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_net_URLClassLoader__24RemoteResource$class_object;

#endif	/* _JC_java_net_URLClassLoader__24RemoteResource_H_ */

==> jc-1.4.6.tar.gz: java/net/URLClassLoader__24RemoteResource.h <==
// final class java.net.URLClassLoader$RemoteResource

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 7e226663297a0266 java_net_URLClassLoader__24RemoteResource
// @dep_class 9d385c5a860bc53d java_net_URLClassLoader__24Resource

// header file dependencies
// @dep_header java_net_URLClassLoader__24Resource

#include "java/net/URLClassLoader__24Resource.h"

#ifndef _JC_java_net_URLClassLoader__24RemoteResource_H_
#define _JC_java_net_URLClassLoader__24RemoteResource_H_

// Forward structure declarations
struct _jc_java_io_InputStream$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_net_URL$object;
struct _jc_java_net_URLClassLoader__24RemoteURLLoader$object;

// Typedefs
typedef struct _jc_java_net_URLClassLoader__24RemoteResource$sub_refs	_jc_java_net_URLClassLoader__24RemoteResource$sub_refs;
typedef struct _jc_java_net_URLClassLoader__24RemoteResource$sub_nonrefs	_jc_java_net_URLClassLoader__24RemoteResource$sub_nonrefs;
typedef struct _jc_java_net_URLClassLoader__24RemoteResource$refs	_jc_java_net_URLClassLoader__24RemoteResource$refs;
typedef struct _jc_java_net_URLClassLoader__24RemoteResource$nonrefs	_jc_java_net_URLClassLoader__24RemoteResource$nonrefs;
typedef struct _jc_java_net_URLClassLoader__24RemoteResource$object	_jc_java_net_URLClassLoader__24RemoteResource$object;

typedef const struct _jc_java_net_URLClassLoader__24RemoteResource$vmethods	_jc_java_net_URLClassLoader__24RemoteResource$vmethods;
typedef const struct _jc_java_net_URLClassLoader__24RemoteResource$vtable	_jc_java_net_URLClassLoader__24RemoteResource$vtable;
typedef const struct _jc_java_net_URLClassLoader__24RemoteResource$vtype	_jc_java_net_URLClassLoader__24RemoteResource$vtype;

// Constructors
extern void _jc_java_net_URLClassLoader__24RemoteResource$method$_init$2c447d2563fff7fe(_jc_env *, struct _jc_java_net_URLClassLoader__24RemoteResource$object *, struct _jc_java_net_URLClassLoader__24RemoteURLLoader$object *, struct _jc_java_lang_String$object *, struct _jc_java_net_URL$object *, struct _jc_java_io_InputStream$object *, jint) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_io_InputStream$object *_jc_java_net_URLClassLoader__24RemoteResource$method$getInputStream$13cf75a12cabb343(_jc_env *, struct _jc_java_net_URLClassLoader__24RemoteResource$object *) _JC_JCNI_ATTR;
extern jint _jc_java_net_URLClassLoader__24RemoteResource$method$getLength$b9eaa8ec0a00f23d(_jc_env *, struct _jc_java_net_URLClassLoader__24RemoteResource$object *) _JC_JCNI_ATTR;
extern struct _jc_java_net_URL$object *_jc_java_net_URLClassLoader__24RemoteResource$method$getURL$f8efe3e882b98c02(_jc_env *, struct _jc_java_net_URLClassLoader__24RemoteResource$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_net_URLClassLoader__24RemoteResource$method_info$getInputStream$13cf75a12cabb343;
extern _jc_method _jc_java_net_URLClassLoader__24RemoteResource$method_info$getLength$b9eaa8ec0a00f23d;
extern _jc_method _jc_java_net_URLClassLoader__24RemoteResource$method_info$getURL$f8efe3e882b98c02;

// Virtual methods structure
struct _jc_java_net_URLClassLoader__24RemoteResource$vmethods {
	struct _jc_java_io_InputStream$object	*(*getInputStream$13cf75a12cabb343)(_jc_env *, struct _jc_java_net_URLClassLoader__24RemoteResource$object *) _JC_JCNI_ATTR;
	jint	(*getLength$b9eaa8ec0a00f23d)(_jc_env *, struct _jc_java_net_URLClassLoader__24RemoteResource$object *) _JC_JCNI_ATTR;
	struct _jc_java_net_URL$object	*(*getURL$f8efe3e882b98c02)(_jc_env *, struct _jc_java_net_URLClassLoader__24RemoteResource$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_net_URLClassLoader__24RemoteResource$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_net_URLClassLoader__24Resource$vmethods	java_net_URLClassLoader__24Resource;
	_jc_java_net_URLClassLoader__24RemoteResource$vmethods	java_net_URLClassLoader__24RemoteResource;
};

// Vtype
struct _jc_java_net_URLClassLoader__24RemoteResource$vtype {
	_jc_type			type;
	_jc_java_net_URLClassLoader__24RemoteResource$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_net_URLClassLoader__24RemoteResource$sub_refs {
	struct _jc_java_net_URL$object	*url;
	struct _jc_java_io_InputStream$object	*stream;
};

// Reference instance fields (object)
struct _jc_java_net_URLClassLoader__24RemoteResource$refs {
    _jc_java_net_URLClassLoader__24RemoteResource$sub_refs	java_net_URLClassLoader__24RemoteResource;
    _jc_java_net_URLClassLoader__24Resource$sub_refs	java_net_URLClassLoader__24Resource;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_net_URLClassLoader__24RemoteResource$sub_nonrefs {
	jint	length;
};

// Non-reference instance fields (object)
struct _jc_java_net_URLClassLoader__24RemoteResource$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_net_URLClassLoader__24Resource$sub_nonrefs	java_net_URLClassLoader__24Resource;
    _jc_java_net_URLClassLoader__24RemoteResource$sub_nonrefs	java_net_URLClassLoader__24RemoteResource;
};

// Object instance structure
struct _jc_java_net_URLClassLoader__24RemoteResource$object {
	_jc_java_net_URLClassLoader__24RemoteResource$refs	refs[0];
	_jc_word		lockword;
	_jc_java_net_URLClassLoader__24RemoteResource$vtype	*vtype;
	_jc_java_net_URLClassLoader__24RemoteResource$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_net_URLClassLoader__24RemoteResource$vtype _jc_java_net_URLClassLoader__24RemoteResource$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_net_URLClassLoader__24RemoteResource, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_net_URLClassLoader__24RemoteResource$class_object;

#endif	/* _JC_java_net_URLClassLoader__24RemoteResource_H_ */
